/** Use LSAC_choice.dta **/

/** Back up for footnote 50 **/
tab esq59 if esq57==1
tab esq59 if esq57==2
tab esq59 if esq58==1
tab esq59 if esq58==2


/**** OBTAINING SAMPLE ****/      
/* 1. Dropping those students who give 'not admitted' as reason for not attending 1st choice school **/ 

drop if esq61a==1

/* 2. Cleaning data - according to codebook these people should skip to esq62 and not answer esq61! **/   

replace esq61a=. if esq59==1  
replace esq61b=. if esq59==1 
replace esq61c=. if esq59==1 

/* 3. Keeping only those students for whom all explanatory vars are available **/   
keep if zfygpa!=. & race1!="" & zlsat!=. & zugpa!=. & gender!="" & tier!=. & esq57!=. 

count

/** Back up for text on page 1833 **/
tab esq59
tab esq59 if race1=="black"
tab esq59 if race1=="white"

/* 4. Dropping those students who were accepted by only 1 school */   drop if esq58==1 

count

/* 5. CHOICE DUMMY : =1 for students not at their 1st choice school, =0 for students at their 1st choice school **/   

gen choice2=1  
replace choice2=0 if esq59==1 

/* 6. TABLE 4: LSAT and UGPA Means for First and Second-or-lower Choice**/

tab choice2 race1

table race1 if choice2==0, c(mean lsat sd lsat mean ugpa sd ugpa) f(%9.2f)

table race1 if choice2==1, c(mean lsat sd lsat mean ugpa sd ugpa) f(%9.2f) 

tab choice2 race1, nofreq col

/* 7. TABLE 5: FYGPA - with choice dummy **/   

xi: reg zfygpa asian black hisp other male tier choice2 esq57 

xi: reg zfygpa male tier choice2 esq57  if race1=="black"
	
xi: reg zfygpa male tier choice2 esq57  if race1=="white"

/* 8. TABLE 6: PASS_BAR - with choice dummy **/  

xi: logit pass_bar asian black hisp other male tier choice2 esq57 

xi: logit pass_bar male tier choice2 esq57  if race1=="black"

xi: logit pass_bar male tier choice2 esq57  if race1=="white"

xi: logit pass_bar zfygpa asian black hisp other male tier choice2 esq57 

xi: logit pass_bar zfygpa male tier choice2 esq57  if race1=="black"

xi: logit pass_bar zfygpa male tier choice2 esq57  if race1=="white"

xi: logit pass_bar ugpa lsat asian black hisp other male tier choice2 esq57 

xi: logit pass_bar ugpa lsat male tier choice2 esq57  if race1=="black"

xi: logit pass_bar ugpa lsat male tier choice2 esq57  if race1=="white"



log close


